@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-boxplot-item.h,v 1.5 2000/10/27 18:22:45 trow Exp $ */
+/* $Id: guppi-boxplot-item.h,v 1.6 2001/01/16 23:36:00 trow Exp $ */
 
 /*
  * guppi-boxplot-item.h
@@ -28,7 +28,7 @@
 #ifndef _INC_GUPPI_BOXPLOT_ITEM_H
 #define _INC_GUPPI_BOXPLOT_ITEM_H
 
-#include <gnome.h>
+/* #include <gnome.h> */
 #include <guppi-defs.h>
 #include <guppi-canvas-item.h>
 
@@ -64,4 +64,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_BOXPLOT_ITEM_H */
 
-/* $Id: guppi-boxplot-item.h,v 1.5 2000/10/27 18:22:45 trow Exp $ */
+/* $Id: guppi-boxplot-item.h,v 1.6 2001/01/16 23:36:00 trow Exp $ */
