@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-scatter-style.h,v 1.8 2000/10/27 18:22:49 trow Exp $ */
+/* $Id: guppi-scatter-style.h,v 1.9 2001/01/16 23:36:04 trow Exp $ */
 
 /*
  * guppi-scatter-style.h
@@ -28,7 +28,7 @@
 #ifndef _INC_GUPPI_SCATTER_STYLE_H
 #define _INC_GUPPI_SCATTER_STYLE_H
 
-#include <gnome.h>
+/* #include <gnome.h> */
 #include <guppi-style.h>
 #include <guppi-color-gradient.h>
 #include <guppi-defs.h>
@@ -145,4 +145,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SCATTER_STYLE_H */
 
-/* $Id: guppi-scatter-style.h,v 1.8 2000/10/27 18:22:49 trow Exp $ */
+/* $Id: guppi-scatter-style.h,v 1.9 2001/01/16 23:36:04 trow Exp $ */
