@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-slinreg-item.h,v 1.8 2000/10/27 18:22:50 trow Exp $ */
+/* $Id: guppi-slinreg-item.h,v 1.9 2001/01/16 23:36:05 trow Exp $ */
 
 /*
  * guppi-slinreg-item.h
@@ -28,7 +28,7 @@
 #ifndef _INC_GUPPI_SLINREG_ITEM_H
 #define _INC_GUPPI_SLINREG_ITEM_H
 
-#include <gnome.h>
+/* #include <gnome.h> */
 #include <libart_lgpl/art_svp.h>
 
 #include <guppi-canvas-item.h>
@@ -69,4 +69,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SLINREG_ITEM_H */
 
-/* $Id: guppi-slinreg-item.h,v 1.8 2000/10/27 18:22:50 trow Exp $ */
+/* $Id: guppi-slinreg-item.h,v 1.9 2001/01/16 23:36:05 trow Exp $ */
