@@ -26,7 +26,9 @@
 #ifndef _INC_PYTHON_LOAD_H
 #define _INC_PYTHON_LOAD_H
 
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <libgnomeui/gnome-app.h>
+
 #include <guppi-defs.h>
 
 BEGIN_GUPPI_DECLS
@@ -39,4 +41,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_PYTHON_LOAD_H */
 
-/* $Id: python-load.h,v 1.3 2000/10/27 18:22:56 trow Exp $ */
+/* $Id: python-load.h,v 1.4 2001/01/16 23:36:10 trow Exp $ */
