@@ -5,6 +5,7 @@
  * guppi-category.c
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org>
  *
@@ -69,185 +70,43 @@ guppi_category_finalize (GtkObject * obj)
     parent_class->finalize (obj);
 }
 
+/* ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** */
+
+struct OutPair {
+  GuppiXMLDocument *doc;
+  xmlNodePtr node;
+};
+
 static void
 xml_cont_fn (const gchar *str, code_t code, gpointer data)
 {
-  GuppiOutputXML *out = GUPPI_OUTPUT_XML (data);
+  struct OutPair *pair = (struct OutPair *) data;
+  gchar buf[64];
+  xmlNodePtr cat_node;
 
-  guppi_output_xml_tag (out, "Category");
+  cat_node = xmlNewNode (pair->doc->ns, "Category");
 
-  guppi_output_xml_element (out, "cat_name", str);
-  guppi_output_xml_elementf (out, "cat_code", "%d", (gint)code);
-
-  guppi_output_xml_end_tag_check (out, "Category");
-}
-
-static void
-write_xml_content (GuppiData *data, GuppiOutputXML *out)
-{
-  guppi_category_foreach (GUPPI_CATEGORY (data), xml_cont_fn, out);
-}
-
-static GuppiData *
-create_xml_object (GuppiAttributesXML *ax)
-{
-  return guppi_category_new ();
-}
-
-/** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** **/
-
-typedef struct _CatParse CatParse;
-struct _CatParse {
-  gboolean in_cat, in_name, in_code;
-  gchar *name;
-  gint code;
-  GuppiCategory *cat;
-};
-
-static CatParse *
-cp_new (GuppiData *d)
-{
-  CatParse *cp = guppi_new0 (CatParse, 1);
-
-  cp->cat = GUPPI_CATEGORY (d);
-  guppi_ref (d);
-
-  return cp;
-}
-
-static void
-cp_free (gpointer p)
-{
-  CatParse *cp = (CatParse *)p;
-
-  guppi_free (cp->name);
-  guppi_unref0 (cp->cat);
-
-  guppi_free (cp);
-}
-
-static GuppiContextXML *
-begin_misc (const CHAR *name, const CHAR **attr, gpointer ud)
-{
-  CatParse *cp = (CatParse *)ud;
-  gboolean parse_error = FALSE;
-
-  g_return_val_if_fail (cp, NULL);
-
-  if (!strcmp (name, "gpi:Category")) {
-
-    if (cp->in_cat || cp->in_name || cp->in_code)
-      parse_error = TRUE;
-    else {
-      cp->in_cat = TRUE;
-      guppi_free (cp->name);
-      cp->name = NULL;
-    }
-
-  } else if (!strcmp (name, "gpi:cat_name")) {
-
-    if ( (! cp->in_cat) || cp->in_name || cp->in_code)
-      parse_error = TRUE;
-    else {
-      cp->in_name = TRUE;
-    }
-
-  } else if (!strcmp (name, "gpi:cat_code")) {
-
-    if ( (! cp->in_cat) || cp->in_name || cp->in_code)
-      parse_error = TRUE;
-    else {
-      cp->in_code = TRUE;
-    }
-  }
-
-  if (parse_error)
-    g_warning ("Parse error.");
+  xmlNewChild (cat_node, pair->doc->ns, "name", str);
   
-  return NULL;
+  g_snprintf (buf, 64, "%d", (gint) code);
+  xmlNewChild (cat_node, pair->doc->ns, "code", buf);
+  
+  xmlAddChild (pair->node, cat_node);
 }
 
-static void
-end_misc (const CHAR *name, gpointer ud)
+static xmlNodePtr
+export_xml_content (GuppiData *data, GuppiXMLDocument *doc)
 {
-  CatParse *cp = (CatParse *)ud;
+  struct OutPair pair;
+  
+  pair.doc = doc;
+  pair.node = xmlNewNode (doc->ns, "Content");
+  
+  guppi_category_foreach (GUPPI_CATEGORY (data), xml_cont_fn, &pair);
 
-  g_return_if_fail (cp);
-
-  if (!strcmp (name, "gpi:Category")) {
-
-    cp->in_cat = FALSE;
-    if (cp->name == NULL)
-      g_warning ("No name defined.");
-
-    guppi_category_define (cp->cat, cp->name, cp->code);
-    guppi_free (cp->name);
-    cp->name = NULL;
-
-  } else if (!strcmp (name, "gpi:cat_name")) {
-
-    cp->in_name = FALSE;
-    if (cp->name == NULL)
-      g_warning ("No name defined.");
-
-  } else if (!strcmp (name, "gpi:cat_code")) {
-
-    cp->in_code = FALSE;
-
-  }
+  return pair.node;
 }
 
-static void
-process_chars (const CHAR *s, gint len, gpointer ud)
-{
-  CatParse *cp = (CatParse *)ud;
-  gchar *str;
-
-  g_return_if_fail (cp);
-
-  str = guppi_strndup (s, len);
-
-  if (cp->in_name) {
-
-    if (cp->name) {
-      g_warning ("redefining name: %s -> %s", cp->name, str);
-      guppi_free (str);
-    }
-    cp->name = str;
-    str = NULL;
-
-  } else if (cp->in_code) {
-
-    cp->code = atoi (str);
-    
-  } else {
-    
-    g_warning ("Stray characters: %s", str);
-
-  }
-
-  guppi_free (str);
-}
-
-
-static GuppiContextXML *
-content_xml_context (GuppiData *d, GuppiAttributesXML *ax)
-{
-  GuppiContextXML *ctx;
-  CatParse *cp;
-
-  ctx = guppi_context_xml_new ();
-  guppi_context_xml_set_begin_element_fn (ctx, begin_misc);
-  guppi_context_xml_set_end_element_fn (ctx, end_misc);
-  guppi_context_xml_set_characters_fn (ctx, process_chars);
-
-  cp = cp_new (d);
-  guppi_context_xml_set_user_data_destroy_fn (ctx, cp, cp_free);
-
-  return ctx;
-}
-
-/** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** **/
 
 static void
 guppi_category_class_init (GuppiCategoryClass * klass)
@@ -259,9 +118,7 @@ guppi_category_class_init (GuppiCategoryClass * klass)
 
   data_class->type_name = _("Category");
   data_class->impl_type = GUPPI_TYPE_CATEGORY_IMPL;
-  data_class->write_xml_content = write_xml_content;
-  data_class->create_xml_object = create_xml_object;
-  data_class->content_xml_context = content_xml_context;
+  data_class->export_xml_content = export_xml_content;
 
   object_class->get_arg = guppi_category_get_arg;
   object_class->set_arg = guppi_category_set_arg;
@@ -299,7 +156,7 @@ guppi_category_new (void)
   return guppi_data_newv (GUPPI_TYPE_CATEGORY, NULL, 0, NULL);
 }
 
-/****************************************************************************/
+/**************************************************************************/
 
 /* Data Op Stuff */
 
@@ -326,7 +183,7 @@ op_define (GuppiData * d, GuppiDataOp * op)
   impl_class->define (impl, cat_op->name, cat_op->code);
 }
 
-/*****************************************************************************/
+/***************************************************************************/
 
 gsize guppi_category_size (GuppiCategory * cat)
 {
