@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-data-init.h,v 1.3 2000/02/09 21:04:56 trow Exp $ */
+/* $Id: guppi-data-init.h,v 1.7 2000/10/27 18:22:58 trow Exp $ */
 
 /*
  * guppi-data-init.h
@@ -28,9 +28,14 @@
 #ifndef _INC_GUPPI_DATA_INIT_H
 #define _INC_GUPPI_DATA_INIT_H
 
-void guppi_data_init(void);
+#include <guppi-defs.h>
 
+BEGIN_GUPPI_DECLS 
+
+void guppi_data_init (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_DATA-INIT_H */
 
-/* $Id: guppi-data-init.h,v 1.3 2000/02/09 21:04:56 trow Exp $ */
+/* $Id: guppi-data-init.h,v 1.7 2000/10/27 18:22:58 trow Exp $ */
