@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-scalar.h,v 1.18 2000/10/27 18:22:59 trow Exp $ */
+/* $Id: guppi-seq-scalar.h,v 1.19 2001/01/16 23:36:22 trow Exp $ */
 
 /*
  * guppi-seq-scalar.h
@@ -28,7 +28,7 @@
 #ifndef _INC_GUPPI_SEQ_SCALAR_H
 #define _INC_GUPPI_SEQ_SCALAR_H
 
-#include <gtk/gtk.h>
+/* #include <gtk/gtk.h> */
 #include "guppi-seq.h"
 #include "guppi-seq-boolean.h"
 
@@ -114,4 +114,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SEQ_SCALAR_H */
 
-/* $Id: guppi-seq-scalar.h,v 1.18 2000/10/27 18:22:59 trow Exp $ */
+/* $Id: guppi-seq-scalar.h,v 1.19 2001/01/16 23:36:22 trow Exp $ */
