@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-object-barchart.c,v 1.13 2001/02/26 20:53:27 trow Exp $ */
+/* $Id: guppi-object-barchart.c,v 1.16 2001/05/06 08:26:44 trow Exp $ */
 
 /*
  * guppi-object-barchart.c
@@ -48,10 +48,13 @@ enum {
   ARG_COLUMN_LABELS,
   ARG_COLUMN_COLORS,
   ARG_COLUMN_COLORS_RGB,
+  ARG_LEGEND_REVERSED,
   ARG_LEGEND_FONT,
   ARG_AXIS_FONT,
   ARG_ROTATE_X_AXIS_LABELS,
   ARG_ROTATE_Y_AXIS_LABELS,
+  ARG_STACKED,
+  ARG_NORMALIZE_STACKS,
 
   ARG_BAR_CALLBACK1,
   ARG_BAR_CALLBACK1_DATA,
@@ -169,6 +172,10 @@ guppi_object_barchart_set_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
 	RGB_TO_RGBA (((guint32 *) GTK_VALUE_POINTER (*arg))[i], 0xff);
     break;
 
+  case ARG_LEGEND_REVERSED:
+    obar->legend_reversed = GTK_VALUE_BOOL (*arg);
+    break;
+
   case ARG_LEGEND_FONT:
     guppi_refcounting_assign (obar->legend_font,
 			      GNOME_FONT (GTK_VALUE_POINTER (*arg)));
@@ -188,6 +195,14 @@ guppi_object_barchart_set_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
     break;
 
 
+  case ARG_STACKED:
+    obar->stacked = GTK_VALUE_BOOL (*arg);
+    break;
+  case ARG_NORMALIZE_STACKS:
+    obar->normalize_stacks = GTK_VALUE_BOOL (*arg);
+    break;
+
+
   case ARG_BAR_CALLBACK1:
     obar->bar_callback1 = GTK_VALUE_POINTER (*arg);
     break;
@@ -267,6 +282,7 @@ guppi_object_barchart_set_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
     obar->legend_callback3_name = guppi_strdup (GTK_VALUE_POINTER (*arg));
     break;
 
+
   default:
     break;
   };
@@ -304,7 +320,7 @@ guppi_object_barchart_finalize (GtkObject * obj)
     parent_class->finalize (obj);
 }
 
-/*****************************************************************************/
+/***************************************************************************/
 
 static GuppiData *
 build_bar_data(GuppiObjectBarchart *obar) 
@@ -335,7 +351,8 @@ build_bar_data(GuppiObjectBarchart *obar)
 }
 
 static GuppiSeqString *
-build_bar_labels(GuppiObjectBarchart * obar, int count, gchar ** source_labels) 
+build_bar_labels(GuppiObjectBarchart * obar, int count, 
+		 gchar ** source_labels, gboolean reversed) 
 {
   GuppiSeqString *labels;
   gint i;
@@ -343,20 +360,22 @@ build_bar_labels(GuppiObjectBarchart * obar, int count, gchar ** source_labels)
   labels = GUPPI_SEQ_STRING (guppi_seq_string_new ());
 
   for (i = 0; i < count; ++i)
-    guppi_seq_string_append (labels, source_labels[i]);
+    guppi_seq_string_append (labels, source_labels[ (reversed) ? 
+						  (count-1-i) : i]);
 
   return labels;
 }
 
 static GuppiSeqStyle *
-build_bar_colors(GuppiObjectBarchart * obar) 
+build_bar_colors(GuppiObjectBarchart * obar, gboolean reversed) 
 {
   GuppiSeqStyle *col_colors;
   gint i;
   col_colors = GUPPI_SEQ_STYLE (guppi_seq_style_new ());
   for (i = 0; i < obar->data_cols; ++i) {
     GuppiStyle *sty = guppi_style_new ();
-    guppi_style_set_color (sty, obar->col_colors[i]);
+    guppi_style_set_color (sty, obar->col_colors[ (reversed) ?
+						(obar->data_cols-1-i) : i]);
     guppi_seq_style_append (col_colors, sty);
     guppi_unref (sty);
   }
@@ -371,9 +390,12 @@ update (GuppiObject *obj)
   GuppiElementState *legend_state = NULL;
   GuppiElementState *bottom_axis_state = NULL;
   GuppiElementState *left_axis_state = NULL;
+  GuppiElementState *frame_state = NULL;
   GuppiSeqString *row_labels = NULL;
   GuppiSeqString *col_labels = NULL;
+  GuppiSeqString *col_labels_rev = NULL;
   GuppiSeqStyle *col_colors = NULL;
+  GuppiSeqStyle *col_colors_rev = NULL;
   GuppiData *data;
   GnomeFont *font;
   
@@ -404,17 +426,20 @@ update (GuppiObject *obj)
   data = build_bar_data (obar);
 
   if (obar->row_labels) {
-    row_labels = build_bar_labels (obar, obar->data_rows, obar->row_labels);
+    row_labels = build_bar_labels (obar, obar->data_rows, obar->row_labels, FALSE);
   }
 
   /* FIXME: check for construction of legends. */
 
   if (obar->legend_view && obar->col_labels) {
-    col_labels = build_bar_labels (obar, obar->data_cols, obar->col_labels);
+    col_labels = build_bar_labels (obar, obar->data_cols, obar->col_labels, FALSE);
+    col_labels_rev = build_bar_labels (obar, obar->data_cols, obar->col_labels, 
+				       obar->legend_reversed);
   }
 
   if (obar->col_colors) {
-    col_colors = build_bar_colors (obar);
+    col_colors = build_bar_colors (obar, FALSE);
+    col_colors_rev = build_bar_colors (obar, obar->legend_reversed);
   }
   
 
@@ -424,6 +449,8 @@ update (GuppiObject *obj)
 		 "row_labels", row_labels,
 		 "column_labels", col_labels,
 		 "column_styles", col_colors,
+		 "stacked", obar->stacked,
+		 "normalize_stacks", obar->normalize_stacks,
 		 NULL);
   
   guppi_element_state_changed (barchart_state);
@@ -453,6 +480,13 @@ update (GuppiObject *obj)
   guppi_element_state_changed (left_axis_state);
   guppi_element_view_changed_size (obar->left_axis_view);
 
+
+  frame_state = guppi_element_view_state(obar->frame_view);
+  guppi_ref (frame_state);
+
+  guppi_element_state_changed (frame_state);
+  guppi_element_view_changed_size (obar->frame_view);
+
   
   if (col_labels != NULL) {
 
@@ -462,8 +496,8 @@ update (GuppiObject *obj)
 
 
     gtk_object_set (GTK_OBJECT (legend_state),
-		   "labels", col_labels,
-		   "styles", col_colors,
+		   "labels", col_labels_rev,
+		   "styles", col_colors_rev,
 		   "label_font", font,
 		   NULL);
 
@@ -478,10 +512,13 @@ update (GuppiObject *obj)
   guppi_unref (legend_state);			   
   guppi_unref (bottom_axis_state);
   guppi_unref (left_axis_state);  
+  guppi_unref (frame_state);  
   guppi_unref (data);
   guppi_unref (row_labels);
   guppi_unref (col_labels);
   guppi_unref (col_colors);  
+  guppi_unref (col_labels_rev);
+  guppi_unref (col_colors_rev);  
 }
 
 
@@ -497,17 +534,21 @@ build (GuppiObject * obj, double hsize, double vsize)
   GuppiData *data;
   GuppiSeqString *row_labels = NULL;
   GuppiSeqString *col_labels = NULL;
+  GuppiSeqString *col_labels_rev = NULL;
   GuppiSeqStyle *col_colors = NULL;
+  GuppiSeqStyle *col_colors_rev = NULL;
 
   GuppiElementState *barchart_state;
   GuppiElementState *legend_state = NULL;
   GuppiElementState *left_axis_state;
   GuppiElementState *bottom_axis_state;
+  GuppiElementState *frame_state = NULL;
 
   GuppiElementView *barchart_view;
   GuppiElementView *legend_view = NULL;
   GuppiElementView *left_axis_view;
   GuppiElementView *bottom_axis_view;
+  GuppiElementView *frame_view = NULL;
 
   const double outer_margin = 3.6;
   const double inner_gap = 3.6;
@@ -530,18 +571,21 @@ build (GuppiObject * obj, double hsize, double vsize)
 
   /* Build up data objects for our labels. */
   if (obar->row_labels) {
-    row_labels = build_bar_labels (obar, obar->data_rows, obar->row_labels);
+    row_labels = build_bar_labels (obar, obar->data_rows, obar->row_labels, FALSE);
   }
 
   if (obar->col_labels) {
-    col_labels = build_bar_labels (obar, obar->data_cols, obar->col_labels);
+    col_labels = build_bar_labels (obar, obar->data_cols, obar->col_labels, FALSE);
+    col_labels_rev = build_bar_labels (obar, obar->data_cols, obar->col_labels, 
+				       obar->legend_reversed);
   }
 
 
   /* Build up our color data */
 
   if (obar->col_colors) {
-    col_colors = build_bar_colors (obar);
+    col_colors = build_bar_colors (obar, FALSE);
+    col_colors_rev = build_bar_colors (obar, obar->legend_reversed);
   }
 
   barchart_state = guppi_element_state_new ("barchart",
@@ -549,6 +593,9 @@ build (GuppiObject * obj, double hsize, double vsize)
 					    "row_labels", row_labels,
 					    "column_labels", col_labels,
 					    "column_styles", col_colors,
+					    "stacked", obar->stacked,
+					    "normalize_stacks",
+					    obar->normalize_stacks,
 					    NULL);
   barchart_view = guppi_element_state_make_view (barchart_state);
 
@@ -575,6 +622,10 @@ build (GuppiObject * obj, double hsize, double vsize)
   left_axis_view = guppi_element_state_make_view (left_axis_state);
   guppi_element_view_set_tool_blocking (left_axis_view, TRUE);
 
+
+  frame_state = guppi_element_state_new ("frame", NULL);
+  frame_view = guppi_element_state_make_view (frame_state);
+
   guppi_element_view_connect (barchart_view, SHARED_X_MARKERS,
 			      bottom_axis_view, SHARED_X_MARKERS);
 
@@ -587,16 +638,25 @@ build (GuppiObject * obj, double hsize, double vsize)
   guppi_element_view_connect (barchart_view, SHARED_Y_VIEW,
 			      left_axis_view, SHARED_Y_VIEW);
 
+  guppi_element_view_connect (barchart_view, SHARED_X_VIEW,
+			      frame_view, SHARED_X_VIEW);
 
-  if (col_labels != NULL) {
+  guppi_element_view_connect (barchart_view, SHARED_Y_VIEW,
+			      frame_view, SHARED_Y_VIEW);
+
+  guppi_element_view_connect (barchart_view, SHARED_Y_MARKERS,
+			      frame_view, SHARED_Y_MARKERS);
+
+
+  if (col_labels_rev != NULL) {
 
     font = obar->legend_font;
     if (font == NULL)
       font = guppi_default_font ();
 
     legend_state = guppi_element_state_new ("legend",
-					    "labels", col_labels,
-					    "styles", col_colors,
+					    "labels", col_labels_rev,
+					    "styles", col_colors_rev,
 					    "label_font", font, NULL);
 
     legend_view = guppi_element_state_make_view (legend_state);
@@ -613,7 +673,7 @@ build (GuppiObject * obj, double hsize, double vsize)
 
   /* Do the layout */
 
-  guppi_group_view_layout_flush_top (grp_view, barchart_view, outer_margin);
+  guppi_group_view_layout_flush_top (grp_view, frame_view, outer_margin);
 
   guppi_group_view_layout_natural_height (grp_view, bottom_axis_view);
   guppi_group_view_layout_flush_bottom (grp_view, bottom_axis_view,
@@ -622,34 +682,37 @@ build (GuppiObject * obj, double hsize, double vsize)
   guppi_group_view_layout_natural_width (grp_view, left_axis_view);
   guppi_group_view_layout_flush_left (grp_view, left_axis_view, outer_margin);
 
-  guppi_group_view_layout_hbox2 (grp_view, left_axis_view, barchart_view,
+  guppi_group_view_layout_hbox2 (grp_view, left_axis_view, frame_view,
 				 inner_gap);
-  guppi_group_view_layout_vbox2 (grp_view, barchart_view, bottom_axis_view,
+  guppi_group_view_layout_vbox2 (grp_view, frame_view, bottom_axis_view,
 				 inner_gap);
 
   if (legend_view) {
 
     guppi_group_view_layout_flush_right (grp_view, legend_view, outer_margin);
-    guppi_group_view_layout_horizontally_adjacent (grp_view, barchart_view,
+    guppi_group_view_layout_horizontally_adjacent (grp_view, frame_view,
 						   legend_view, inner_gap);
     guppi_group_view_layout_natural_height (grp_view, legend_view);
     guppi_group_view_layout_natural_width (grp_view, legend_view);
     guppi_group_view_layout_same_y_center (grp_view, legend_view,
-					   barchart_view);
+					   frame_view);
 
   } else {
 
-    guppi_group_view_layout_flush_right (grp_view, barchart_view,
+    guppi_group_view_layout_flush_right (grp_view, frame_view,
 					 outer_margin);
 
   }
 
+  guppi_group_view_layout_same_place (grp_view, frame_view, barchart_view);
+
   /* Remember our view objects */
 
   obar->legend_view = legend_view;
   obar->barchart_view = barchart_view;
   obar->bottom_axis_view = bottom_axis_view;
   obar->left_axis_view = left_axis_view;
+  obar->frame_view = frame_view;
 
 
   /* Clean up after ourselves... */
@@ -658,6 +721,8 @@ build (GuppiObject * obj, double hsize, double vsize)
   guppi_unref (row_labels);
   guppi_unref (col_labels);
   guppi_unref (col_colors);
+  guppi_unref (col_labels_rev);
+  guppi_unref (col_colors_rev);
 
   guppi_unref (barchart_state);
   guppi_unref (bottom_axis_state);
@@ -702,17 +767,23 @@ clicked_box_cb (GuppiCanvasItem * item,
 
   case 1:
     if (obar->legend_callback1)
-      obar->legend_callback1 (box, obar->legend_callback1_data);
+      obar->legend_callback1 ((obar->legend_reversed) ?
+			      (obar->data_cols - 1 - box) : box, 
+			      obar->legend_callback1_data);
     break;
-
+    
   case 2:
     if (obar->legend_callback2)
-      obar->legend_callback2 (box, obar->legend_callback2_data);
+      obar->legend_callback2 ((obar->legend_reversed) ?
+			      (obar->data_cols - 1 - box) : box, 
+			      obar->legend_callback2_data);
     break;
-
+    
   case 3:
     if (obar->legend_callback3)
-      obar->legend_callback3 (box, obar->legend_callback3_data);
+      obar->legend_callback3 ((obar->legend_reversed) ?
+			      (obar->data_cols - 1 - box) : box, 
+			      obar->legend_callback3_data);
     break;
 
   default:
@@ -741,7 +812,7 @@ item_init (GuppiObject * obj, GuppiCanvasItem * item)
 
 }
 
-/*****************************************************************************/
+/***************************************************************************/
 
 #define add_arg(str, t, symb) \
 gtk_object_add_arg_type("GuppiObjectBarchart::" str, t, GTK_ARG_WRITABLE, symb)
@@ -769,6 +840,7 @@ guppi_object_barchart_class_init (GuppiObjectBarchartClass * klass)
   add_arg ("column_labels", GTK_TYPE_POINTER, ARG_COLUMN_LABELS);
   add_arg ("column_colors", GTK_TYPE_POINTER, ARG_COLUMN_COLORS);
   add_arg ("column_colors_rgb", GTK_TYPE_POINTER, ARG_COLUMN_COLORS_RGB);
+  add_arg ("legend_reversed", GTK_TYPE_BOOL, ARG_LEGEND_REVERSED);
 
   add_arg ("legend_font", GTK_TYPE_POINTER, ARG_LEGEND_FONT);
   add_arg ("axis_font", GTK_TYPE_POINTER, ARG_AXIS_FONT);
@@ -776,6 +848,9 @@ guppi_object_barchart_class_init (GuppiObjectBarchartClass * klass)
   add_arg ("rotate_x_axis_labels", GTK_TYPE_BOOL, ARG_ROTATE_X_AXIS_LABELS);
   add_arg ("rotate_y_axis_labels", GTK_TYPE_BOOL, ARG_ROTATE_Y_AXIS_LABELS);
 
+  add_arg ("stacked", GTK_TYPE_BOOL, ARG_STACKED);
+  add_arg ("normalize_stacks", GTK_TYPE_BOOL, ARG_NORMALIZE_STACKS);
+
   add_arg ("bar_callback1", GTK_TYPE_POINTER, ARG_BAR_CALLBACK1);
   add_arg ("bar_callback1_data", GTK_TYPE_POINTER, ARG_BAR_CALLBACK1_DATA);
   add_arg ("bar_callback1_name", GTK_TYPE_POINTER, ARG_BAR_CALLBACK1_NAME);
@@ -806,7 +881,6 @@ guppi_object_barchart_class_init (GuppiObjectBarchartClass * klass)
   add_arg ("legend_callback3_name", GTK_TYPE_POINTER,
 	   ARG_LEGEND_CALLBACK3_NAME);
 
-
 }
 
 static void
@@ -841,4 +915,4 @@ guppi_object_barchart_new (void)
 
 
 
-/* $Id: guppi-object-barchart.c,v 1.13 2001/02/26 20:53:27 trow Exp $ */
+/* $Id: guppi-object-barchart.c,v 1.16 2001/05/06 08:26:44 trow Exp $ */
