@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-object-barchart.h,v 1.10 2001/02/26 20:53:27 trow Exp $ */
+/* $Id: guppi-object-barchart.h,v 1.12 2001/04/21 18:59:07 cstim Exp $ */
 
 /*
  * guppi-object-barchart.h
@@ -46,6 +46,7 @@ struct _GuppiObjectBarchart {
   gchar **row_labels;
   gchar **col_labels;
   guint32 *col_colors;
+  gboolean legend_reversed;
 
   GnomeFont *legend_font;
   GnomeFont *axis_font;
@@ -53,6 +54,9 @@ struct _GuppiObjectBarchart {
   gboolean rot_x_axis_labels;
   gboolean rot_y_axis_labels;
 
+  gboolean stacked;
+  gboolean normalize_stacks;
+
   void (*bar_callback1) (gint, gint, gpointer);
   gpointer bar_callback1_data;
   gchar *bar_callback1_name;
@@ -81,6 +85,7 @@ struct _GuppiObjectBarchart {
   GuppiElementView *legend_view;
   GuppiElementView *left_axis_view;
   GuppiElementView *bottom_axis_view;
+  GuppiElementView *frame_view;
 };
 
 struct _GuppiObjectBarchartClass {
@@ -105,4 +110,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_OBJECT_BARCHART_H */
 
-/* $Id: guppi-object-barchart.h,v 1.10 2001/02/26 20:53:27 trow Exp $ */
+/* $Id: guppi-object-barchart.h,v 1.12 2001/04/21 18:59:07 cstim Exp $ */
