@@ -1,6 +1,6 @@
 /* This is -*- C -*- */
 /* vim: set sw=2: */
-/* $Id: gnan.h,v 1.2 2000/12/21 22:23:33 trow Exp $ */
+/* $Id: gnan.h,v 1.3 2001/01/16 23:36:39 trow Exp $ */
 
 /*
  * gnan.h
@@ -28,7 +28,8 @@
 #ifndef _INC_GNAN_H
 #define _INC_GNAN_H
 
-#include <gtk/gtk.h>
+/* #include <gtk/gtk.h> */
+#include <glib.h>
 #include <math.h>
 #include "guppi-defs.h"
 
@@ -47,4 +48,4 @@ END_GUPPI_DECLS;
 
 #endif /* _INC_GNAN_H */
 
-/* $Id: gnan.h,v 1.2 2000/12/21 22:23:33 trow Exp $ */
+/* $Id: gnan.h,v 1.3 2001/01/16 23:36:39 trow Exp $ */
