@@ -72,6 +72,8 @@ guppi_context_xml_finalize (GtkObject *obj)
 {
   GuppiContextXML *ctx = GUPPI_CONTEXT_XML (obj);
 
+  guppi_finalized (obj);
+
   /* This properly deallocates any user data */
   guppi_context_xml_set_user_data (ctx, NULL);
 
@@ -141,7 +143,7 @@ guppi_context_xml_new (void)
   return GUPPI_CONTEXT_XML (guppi_type_new (guppi_context_xml_get_type ()));
 }
 
-/*****************************************************************************/
+/***********************************************************************/
 
 void
 guppi_context_xml_set_user_data (GuppiContextXML *ctx, gpointer ud)
@@ -292,13 +294,11 @@ guppi_context_xml_add_element_context (GuppiContextXML *ctx,
   guppi_ref (new_ctx);
 }
 
-/*****************************************************************************/
+/***********************************************************************/
 
 static void
 gtk_iter_hack (void)
 {
-  static gint i = 0;
-
   /*
     It looks like this causes some flaming death... 
     Apparently some code somewhere isn't properly re-enterant.
@@ -307,6 +307,8 @@ gtk_iter_hack (void)
   */
 
 #if 0
+  static gint i = 0;
+  
   if (i == 0) {
     while (gtk_events_pending ())
       gtk_main_iteration ();
@@ -431,7 +433,7 @@ guppi_context_xml_process_end_element (GuppiContextXML *ctx, const CHAR *name)
   }
 }
 
-/*****************************************************************************/
+/***********************************************************************/
 
 void
 guppi_context_xml_warning (GuppiContextXML *xml, const gchar *format_str, ...)
@@ -462,7 +464,7 @@ guppi_context_xml_error (GuppiContextXML *xml, const gchar *format_str, ...)
 
 }
 
-/*****************************************************************************/
+/***********************************************************************/
 
 typedef struct _ContextFrame ContextFrame;
 struct _ContextFrame {
@@ -682,7 +684,7 @@ guppi_context_xml_parse_memory (GuppiContextXML *root_ctx,
   return ret;
 }
 
-/** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** **/
+/* ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** */
 
 static GuppiContextXML *
 debug_begin_element (const CHAR *name, const CHAR **attrs, gpointer foo)
